==> haskell-math-functions-0.1.5.2-3-armv7h.pkg.tar.xz: usr/share/haskell/haskell-math-functions/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: math-functions
version: 0.1.5.2
id: math-functions-0.1.5.2-7a985a285f902888d75b2085436cd768
key: mathf_3LEsvkri95Y0iU7IlgKIu5
license: BSD3
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/math-functions
synopsis: Special functions and Chebyshev polynomials
description:
    This library provides implementations of special mathematical
    functions and Chebyshev polynomials.  These functions are often
    useful in statistical and numerical computing.
category: Math, Numeric
author: Bryan O'\''Sullivan <bos@serpentine.com>,
        Aleksey Khudyakov <alexey.skladnoy@gmail.com>
exposed: True
exposed-modules:
    Numeric.MathFunctions.Constants Numeric.Polynomial
    Numeric.Polynomial.Chebyshev Numeric.SpecFunctions
    Numeric.SpecFunctions.Extra Numeric.Sum
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/math-functions-0.1.5.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/math-functions-0.1.5.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/math-functions-0.1.5.2
hs-libraries: HSmath-functions-0.1.5.2-3LEsvkri95Y0iU7IlgKIu5
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    erf-2.0.0.0-aab48415b057e47fae23d9f8b194cc70
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
    vector-th-unbox-0.2.1.5-8f7270dc4460c13d7b9488d6341118f7
haddock-interfaces: /usr/share/doc/haskell-math-functions/html/math-functions.haddock
haddock-html: /usr/share/doc/haskell-math-functions/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-math-functions-0.1.7.0-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-math-functions/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: math-functions
version: 0.1.7.0
id: math-functions-0.1.7.0-46faa63fe0537168b78e38dab80faf11
key: mathf_BN6S7j0ar3LC4TsnYu0us5
license: BSD3
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/math-functions
synopsis: Special functions and Chebyshev polynomials
description:
    This library provides implementations of special mathematical
    functions and Chebyshev polynomials.  These functions are often
    useful in statistical and numerical computing.
category: Math, Numeric
author: Bryan O'\''Sullivan <bos@serpentine.com>,
        Aleksey Khudyakov <alexey.skladnoy@gmail.com>
exposed: True
exposed-modules:
    Numeric.MathFunctions.Constants Numeric.MathFunctions.Comparison
    Numeric.Polynomial Numeric.Polynomial.Chebyshev
    Numeric.SpecFunctions Numeric.SpecFunctions.Extra Numeric.Sum
hidden-modules: Numeric.SpecFunctions.Internal
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/math-functions-0.1.7.0
library-dirs: /usr/lib/ghc-7.10.3/site-local/math-functions-0.1.7.0
data-dir: /usr/share/arm-linux-ghc-7.10.3/math-functions-0.1.7.0
hs-libraries: HSmath-functions-0.1.7.0-BN6S7j0ar3LC4TsnYu0us5
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    erf-2.0.0.0-aab48415b057e47fae23d9f8b194cc70
    primitive-0.6.1.0-013c88e6ffae491f11ac3b8c0552ce0e
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
    vector-th-unbox-0.2.1.6-b280ccc19afbd942da03aa8e46087198
haddock-interfaces: /usr/share/doc/haskell-math-functions/html/math-functions.haddock
haddock-html: /usr/share/doc/haskell-math-functions/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
